@@ -192,6 +192,7 @@ bool Betamax::showAccountSettingsDialog(QWidget* parent)
 
   QLabel sendUrlLabel(tr("Send URL:"), &dialog);
   QLineEdit sendUrlEdit(d->sendUrl.toString(), &dialog);
+  sendUrlLabel.setInputMethodHints(Qt::ImhUrlCharactersOnly);
 
   QFormLayout* formLayout = dialog.formLayout();
   int row = formLayout->rowCount();
@@ -253,6 +254,7 @@ void Betamax::sendMessage(const Message& message)
 
   // Transmit the request
   QNetworkReply* reply = d->network.get(request, "SendMessage");
+  reply->ignoreSslErrors();
   reply->setProperty("message", QVariant::fromValue(message)); // Remember the message for later use
 }
 
@@ -272,6 +274,34 @@ public:
     addProvider(tr("VoipCheap.com"), "fbba682a-3139-472d-934d-228de216426a", QIcon(":/providers/betamax/voipcheap.com.png"), "https://www.voipcheap.com/myaccount/sendsms.php");
     addProvider(tr("SMSdiscount.com"), "91ac866a-a013-4f84-9def-204c366b8468", QIcon(":/providers/betamax/smsdiscount.com.png"), "https://www.smsdiscount.com/myaccount/sendsms.php");
     addProvider(tr("Lowratevoip.com"), "4a8dead9-6df8-4ff9-adf5-5604bf739755", QIcon(), "https://www.lowratevoip.com/myaccount/sendsms.php");
+    addProvider(tr("Poivy.com"), "7f3086fa-2db7-4619-860f-12c364d79790", QIcon(), "https://www.poivy.com/myaccount/sendsms.php");    
+    addProvider(tr("12voip.com"), "8297063d-38d7-454a-9281-5a538095981a", QIcon(), "https://www.12voip.com/myaccount/sendsms.php");
+    addProvider(tr("ActionVoip.com"), "92924d13-791a-439e-beaf-5752dacdbf63", QIcon(), "https://www.actionvoip.com/myaccount/sendsms.php");
+    addProvider(tr("BudgetSip.com"), "90d36590-b99e-421d-8f60-d45c5180dbfe", QIcon(), "https://www.budgetsip.com/myaccount/sendsms.php");
+    addProvider(tr("CallEasy.com"), "292c0fa5-939d-47b6-80ca-90b1af58de83", QIcon(), "https://www.calleasy.com/myaccount/sendsms.php");
+    addProvider(tr("DialNow.com"), "2d509516-db9c-4499-b4a6-53b2df7a036a", QIcon(), "https://www.dialnow.com/myaccount/sendsms.php");
+    addProvider(tr("FreeCall.com"), "3f08f04a-2180-418a-a959-202dde3c43d2", QIcon(), "https://www.freecall.com/myaccount/sendsms.php");
+    addProvider(tr("InternetCalls.com"), "3205db32-f0aa-47c8-ab09-3e46af38f6b9", QIcon(), "https://www.internetcalls.com/myaccount/sendsms.php");
+    addProvider(tr("InterVoip.com"), "a57774f3-1a4e-437b-b4c2-f5d50f80ee74", QIcon(), "https://www.intervoip.com/myaccount/sendsms.php");
+    addProvider(tr("Jumblo.com"), "2df9685e-6d93-4587-a27c-822da40dde58", QIcon(), "https://www.jumblo.com/myaccount/sendsms.php");
+    addProvider(tr("JustVoip.com"), "13eecbdf-5f64-4888-abf6-0bf55e273c2a", QIcon(), "https://www.justvoip.com/myaccount/sendsms.php");
+    addProvider(tr("NetAppel.fr"), "725aa6de-c47f-458f-91ee-88aaa6ef3c47", QIcon(), "https://www.netappel.fr/myaccount/sendsms.php");
+    addProvider(tr("nonoh.net"), "7f899380-5f36-476c-a128-b6b3681f920f", QIcon(), "https://www.nonoh.net/myaccount/sendsms.php");
+    addProvider(tr("rynga.com"), "c983dedd-528b-4079-bc53-de80fb240ab4", QIcon(), "https://www.rynga.com/myaccount/sendsms.php");
+    addProvider(tr("sipdiscount.com"), "1c91c3e5-910d-44d9-93d9-98468da01d36", QIcon(), "https://www.sipdiscount.com/myaccount/sendsms.php");
+    addProvider(tr("smartvoip.com"), "e0c40844-4887-4ff7-8486-6d349122f5e0", QIcon(), "https://www.smartvoip.com/myaccount/sendsms.php");
+    addProvider(tr("smslisto.com"), "0b6a4e88-985c-4f88-925b-9a63fa12a234", QIcon(), "https://www.smslisto.com/myaccount/sendsms.php");
+    addProvider(tr("sparvoip.de"), "68a7c3db-2dad-4df1-92b8-f1fcc079be84", QIcon(), "https://www.sparvoip.com/myaccount/sendsms.php");
+    addProvider(tr("voipbuster.com"), "857c8bd4-de4f-4bbf-9f7c-617a090494e1", QIcon(), "https://www.voipbuster.com/myaccount/sendsms.php");
+    addProvider(tr("voipbusterpro.com"), "eb17845f-ecab-4c1f-bb89-fdcf820b7941", QIcon(), "https://www.voipbusterpro.com/myaccount/sendsms.php");
+    addProvider(tr("voipcheap.co.uk"), "f784fd68-edfb-4060-9268-8609460d23f1", QIcon(), "https://www.voipcheap.co.uk/myaccount/sendsms.php");
+    addProvider(tr("voipian.com"), "441681d6-1463-4092-8bc5-99491a7da8f6", QIcon(), "https://www.voipian.com/myaccount/sendsms.php");
+    addProvider(tr("voipraider.com"), "8c018e10-9edf-499c-ae67-73571ca1a1ed", QIcon(), "https://www.voipraider.com/myaccount/sendsms.php");
+    addProvider(tr("voipstunt.com"), "9409f44a-8f64-455e-af45-ff1dd29d84de", QIcon(), "https://www.voipstunt.com/myaccount/sendsms.php");
+    addProvider(tr("voipwise.com"), "e4ccb7cb-d32a-4db1-ba8f-91855baf8d26", QIcon(), "https://www.voipwise.com/myaccount/sendsms.php");
+    addProvider(tr("voipzoom.com"), "1737784e-ad65-456a-aa03-af01d7c7365a", QIcon(), "https://www.voipzoom.com/myaccount/sendsms.php");
+    addProvider(tr("webcalldirect.com"), "69aebbcf-54ac-4d63-b5eb-936d1783c1a5", QIcon(), "https://www.webcalldirect.com/myaccount/sendsms.php");
+    
     addProvider(QString(), "a1834119-d9f6-44d5-80b8-5550946d5df7", QIcon(), QString());
   }
 
