@@ -134,6 +134,8 @@ void sms77dePrivate::handleSendMessage(QNetworkReply* reply)
   // Error output
   if ( !success )
     emit self->error( errorCodes.value(data, tr("Unbekannter Fehlercode")) );
+  else
+    self->updateBalance();
 }
 
 //////////////////////////////////////////////////////////////////////////
@@ -214,7 +216,7 @@ void sms77de::sendMessage(const Message& message)
   number.replace(QRegExp("^\\+"), "00");
 
   // Setup the message
-  QUrl url("http://gateway.sms77.de");
+  QUrl url("https://gateway.sms77.de");
   url.addQueryItem("u", d->username);
   url.addQueryItem("p", d->password);
   url.addQueryItem("to", number);
@@ -228,6 +230,7 @@ void sms77de::sendMessage(const Message& message)
 
   // Transmit the request
   QNetworkReply* reply = d->network.get(request, "SendMessage");
+  reply->ignoreSslErrors();
   reply->setProperty("message", QVariant::fromValue(message)); // Remember the message for later use
 }
 
@@ -236,7 +239,7 @@ void sms77de::sendMessage(const Message& message)
 void sms77de::updateBalance()
 {
   // Setup the url
-  QUrl url("http://gateway.sms77.de/balance.php");
+  QUrl url("https://gateway.sms77.de/balance.php");
   url.addQueryItem("u", d->username);
   url.addQueryItem("p", d->password);
 
@@ -245,7 +248,8 @@ void sms77de::updateBalance()
   request.setUrl(url);
 
   // Transmit the request
-  d->network.get(request, "Balance");
+  QNetworkReply* reply = d->network.get(request, "Balance");
+  reply->ignoreSslErrors();
 }
 
 //////////////////////////////////////////////////////////////////////////
